@@ -3,7 +3,7 @@ from sklearn.metrics import ConfusionMatrixDisplay
 from bender.evaluator.interface import Evaluator
 from bender.exporter.exporter import Exporter
 from bender.split_strategy.split_strategy import TrainingDataSet
-from bender.trained_model.interface import TrainedEstimatorModel, TrainedModel
+from bender.trained_model.interface import TrainedClassificationModel, TrainedEstimatorModel, TrainedModel
 
 
 class ConfusionMatrix(Evaluator):
@@ -14,10 +14,15 @@ class ConfusionMatrix(Evaluator):
         self.exporter = exporter
 
     async def evaluate(self, model: TrainedModel, data_set: TrainingDataSet) -> None:
-        if not isinstance(model, TrainedEstimatorModel):
+        if isinstance(model, TrainedEstimatorModel):
+            display = ConfusionMatrixDisplay.from_estimator(
+                model.estimator(), data_set.x_validate, data_set.y_validate.astype(float)
+            )
+        elif isinstance(model, TrainedClassificationModel):
+            predictions = model.predict(data_set.x_validate)
+            display = ConfusionMatrixDisplay.from_predictions(data_set.y_validate, predictions)
+        else:
             return
-        display = ConfusionMatrixDisplay.from_estimator(
-            model.estimator(), data_set.x_validate, data_set.y_validate.astype(float)
-        )
+
         _ = display.ax_.set_title('Confusion Matrix')
         await self.exporter.store_figure(display.figure_)
